command line help
==================================


.. program-output:: python -m pyscreenshot.examples.show --help
    :prompt:


.. program-output:: python -m pyscreenshot.examples.showall --help
    :prompt:

.. program-output:: python -m pyscreenshot.check.speedtest --help
    :prompt:

.. program-output:: python -m pyscreenshot.check.versions --help
    :prompt:
